@@ -38,7 +38,7 @@ class Dialog : public QDialog, public QDeclarativeParserStatus
     Q_PROPERTY(int height READ height WRITE setFixedHeight NOTIFY heightChanged)
     Q_PROPERTY(qreal opacity READ opacity WRITE setOpacity NOTIFY opacityChanged)
     Q_PROPERTY(bool visible READ isVisible WRITE setVisible NOTIFY visibleChanged)
-    Q_PROPERTY(bool focus READ hasFocus WRITE setFocus NOTIFY focusChanged)
+    Q_PROPERTY(bool enabled READ isEnabled WRITE setEnabled NOTIFY enabledChanged)
     Q_PROPERTY(AnchorLine left READ left CONSTANT FINAL)
     Q_PROPERTY(AnchorLine right READ right CONSTANT FINAL)
     Q_PROPERTY(AnchorLine top READ top CONSTANT FINAL)
@@ -50,6 +50,7 @@ class Dialog : public QDialog, public QDeclarativeParserStatus
     Q_PRIVATE_PROPERTY(Dialog::d_func(), QDeclarativeListProperty<QObject> actions READ actions)
     Q_PRIVATE_PROPERTY(Dialog::d_func(), QDeclarativeListProperty<QWidget> content READ content)
     Q_PRIVATE_PROPERTY(Dialog::d_func(), QDeclarativeListProperty<QAbstractButton> buttons READ buttons)
+    Q_PRIVATE_PROPERTY(Dialog::d_func(), bool focus READ hasFocus WRITE setFocus NOTIFY focusChanged)
 
     Q_INTERFACES(QDeclarativeParserStatus)
 
@@ -62,8 +63,6 @@ public:
     qreal opacity() const;
     void setOpacity(qreal opacity);
 
-    void setFocus(bool focus);
-
     bool showingProgressIndicator() const;
     void showProgressIndicator(bool show);
 
@@ -82,6 +81,7 @@ signals:
     void heightChanged();
     void opacityChanged();
     void visibleChanged();
+    void enabledChanged();
     void focusChanged();
 
 protected:
