@@ -179,6 +179,8 @@ public:
 
     QString statusText;
 
+    QString userAgent;
+
     QList<QObject*> dataList;
     QList<QObject*> jsObjectList;
 
@@ -193,6 +195,9 @@ WebPage::WebPage(QObject *parent) :
         this->setNetworkAccessManager(engine->networkAccessManager());
     }
 
+    this->mainFrame()->setScrollBarPolicy(Qt::Horizontal, Qt::ScrollBarAlwaysOff);
+    this->mainFrame()->setScrollBarPolicy(Qt::Vertical, Qt::ScrollBarAlwaysOff);
+
     this->connect(this->mainFrame(), SIGNAL(urlChanged(QUrl)), this, SIGNAL(urlChanged()));
     this->connect(this->mainFrame(), SIGNAL(iconChanged()), this, SIGNAL(iconChanged()));
     this->connect(this->mainFrame(), SIGNAL(titleChanged(QString)), this, SIGNAL(titleChanged()));
@@ -214,6 +219,9 @@ WebPage::WebPage(WebPagePrivate &dd, QObject *parent) :
         this->setNetworkAccessManager(engine->networkAccessManager());
     }
 
+    this->mainFrame()->setScrollBarPolicy(Qt::Horizontal, Qt::ScrollBarAlwaysOff);
+    this->mainFrame()->setScrollBarPolicy(Qt::Vertical, Qt::ScrollBarAlwaysOff);
+
     this->connect(this->mainFrame(), SIGNAL(urlChanged(QUrl)), this, SIGNAL(urlChanged()));
     this->connect(this->mainFrame(), SIGNAL(iconChanged()), this, SIGNAL(iconChanged()));
     this->connect(this->mainFrame(), SIGNAL(titleChanged(QString)), this, SIGNAL(titleChanged()));
@@ -332,6 +340,20 @@ bool WebPage::hasSelection() const {
     return !this->selectedText().isEmpty();
 }
 
+QString WebPage::userAgent() const {
+    Q_D(const WebPage);
+
+    return d->userAgent;
+}
+
+void WebPage::setUserAgent(const QString &agent) {
+    if (agent != this->userAgent()) {
+        Q_D(WebPage);
+        d->userAgent = agent;
+        emit userAgentChanged();
+    }
+}
+
 QDeclarativeComponent* WebPage::newWindowComponent() const {
     Q_D(const WebPage);
 
@@ -432,15 +454,15 @@ QWebPage* WebPage::createWindow(WebWindowType type) {
         return 0;
     }
 
-    WebPage *page = 0;
+    QWebPage *page = 0;
     QDeclarativeContext *creationContext = d->windowComponent->creationContext();
     QDeclarativeContext *context = new QDeclarativeContext(creationContext ? creationContext : qmlContext(this));
 
     if (QObject *obj = d->windowComponent->create(context)) {
-        page = qobject_cast<WebPage*>(obj);
+        page = qobject_cast<QWebPage*>(obj);
 
         if (!page) {
-            page = obj->findChild<WebPage*>();
+            page = obj->findChild<QWebPage*>();
         }
 
         if (page) {
@@ -459,4 +481,8 @@ QWebPage* WebPage::createWindow(WebWindowType type) {
     return page;
 }
 
+QString WebPage::userAgentForUrl(const QUrl &url) const {
+    return this->userAgent().isEmpty() ? QWebPage::userAgentForUrl(url) : this->userAgent();
+}
+
 #include "moc_webpage_p.cpp"
